# Django User States
The Django State connector provides a mechanism similar to groups which manages associating a user with a group based on a manner in which app developers are able to customize the behavior through model polymorphism.

## Installation
1. Add `django_user_states` to your INSTALLED_APPS
2. Run `python3 manage.py migrate` to create the django_user_states models

